@@ -31,4 +31,10 @@ class item():
             time -= 1
             if time <= 0:
                 self.demand = x
-                self.price = round(self.demand * self.multiplier, 2)
\ No newline at end of file
+                self.price = round(self.demand * self.multiplier, 2)
+                self.supply -= self.demand
+                if self.supply <= -1:
+                    self. supply = 0
+                asd = random.randint(1, 10)
+                if asd == 5:
+                    self.supply += int(self.demand / 2)
\ No newline at end of file
